package edu.ucla.loni.debabel.processors.keith;

import edu.ucla.loni.debabel.processors.keith.calculus.CrossProduct;
import edu.ucla.loni.debabel.processors.keith.talairach.DicomToTalairachSpace;
import edu.ucla.loni.debabel.processors.keith.talairach.DicomToTalairachSpaceOld;
import edu.ucla.loni.debabel.processors.keith.talairach.DicomImageSorter;
import edu.ucla.loni.debabel.processors.keith.talairach.RasterRotator;
import edu.ucla.loni.debabel.processors.keith.talairach.TalairachImageReformatter;
import edu.ucla.loni.debabel.processors.keith.talairach.TalairachToMincSpace;
import edu.ucla.loni.moduleio.spi.ProcessorSpi;
import java.util.Locale;
import java.util.Vector;

/**
 * Processor SPI (Service Provider Interface) for Debabeler Standard Library.
 *
 * @version 15 July 2003
 */
public class KeithLibraryProcessorSpi extends ProcessorSpi
{
  /** Name of the vendor who supplied this plug-in. */
  private static String _vendorName = "Laboratory of Neuro Imaging (LONI)";

  /** Version of this plug-in. */
  private static String _version = "1.0.4";

  /** Name of the library of Processors. */
  private static String _libraryName 
                          = "Keith's Processor Library";

  /** Comment pertaining to the library. */
  private static String _libraryComment 
                          = "Author: Ouellette, Created: 15 July 2003";

  /** Constructs a Standard Library Processor SPI. */
  public KeithLibraryProcessorSpi()
    {
      super(_vendorName, _version, _libraryName, _libraryComment);
    }

  /**
   * Returns a brief, human-readable description of this service provider and
   * its associated implementation.
   *
   * @param locale Locale for which the return value should be localized.
   *
   * @return Description of this service provider.
   */
  public String getDescription(Locale locale)
    {
      return _libraryName;
    }

  /**
   * Gets an array of fully-qualified class names of the Processors belonging
   * to the library.
   *
   * @return Fully-qualified class names of the Processors belonging to the
   *         library.
   */
  public String[] getProcessorClassNames()
    {
      Vector names = new Vector();

      // Add the class names
      names.add( CrossProduct.class.getName() );
      names.add( DicomImageSorter.class.getName() );
      names.add( DicomToTalairachSpace.class.getName() );
      names.add( DicomToTalairachSpaceOld.class.getName() );
      names.add( RasterRotator.class.getName() );
      names.add( TalairachImageReformatter.class.getName() );
      names.add( TalairachToMincSpace.class.getName() );

      // Convert the Vector to a String array
      String[] array = new String[ names.size() ];
      for (int i = 0; i < array.length; i++) {
	array[i] = (String)names.elementAt(i);
      }

      // Return the String array
      return array;
    }
}
