/*
COPYRIGHT NOTICE
Copyright (c) 2003  Scott C. Neu, Daniel J. Valentino, and Arthur W. Toga

See README.license for license notices.
 */

package edu.ucla.loni.debabel.processors.vann;

import edu.ucla.loni.dataflow.MetadataTree;
import edu.ucla.loni.flow.OutputNode;
import edu.ucla.loni.flow.Restriction;
import edu.ucla.loni.flow.exceptions.ProcessingException;
import edu.ucla.loni.flow.process.Processor;
import edu.ucla.loni.flow.process.ProcessorProperty;
import edu.ucla.loni.flow.restrictions.SetRestriction;
import java.lang.reflect.Constructor;
import java.util.Vector;
import java.lang.reflect.Array;

/**
 * Processor that produces a null object.
 *
 * @author Bryan C. Vann
 *
 * @version 9 June 2003
 */
public class NullArray extends Processor
{
  /** Description of this Processor. */
  private static String DESC = "Produces a constant value.";

  /** Name of the Output Node. */
  private static String NODE_NAME = "Null";

  /** Name of the Output Node. */
  private static String NODE_DESC = "Null object pointer reference";

  /**
   * Constructs a Constant with default Properties.
   *
   * @param name Name of the Processor.
   *
   * @throws IllegalStringException If the name contains illegal characters.
   */
  public NullArray(String name)
    {
      this(name, _getDefaultProperties());
    }

  /**
   * Constructs an Constant using the specified Properties.
   *
   * @param name Name of the Processor.
   * @param properties Properties for the Processor.
   *
   * @throws IllegalStringException If the name contains illegal characters.
   */
  public NullArray(String name, ProcessorProperty[] properties)
    {
      super(name, DESC);

      // Add the Properties
      _addProperties(_getDefaultProperties(), properties);

      // Create an Output Node for the constant value
      Class type = Array.newInstance(MetadataTree.class, 0).getClass();
      OutputNode outputNode = new OutputNode(NODE_NAME,NODE_DESC,type);
      _addOutputNode(outputNode);
    }

  /**
   * Generates values for the Output Nodes using the current values of the
   * Input Nodes.
   *
   * @throws ProcessingException If an error occurs during processing.
   */
  public void generateOutputValues() throws ProcessingException
    {
      // Set the constant value
      try {
	_setOutputValue(NODE_NAME, null);
      }

      catch (Exception e) {
	String msg = "Unable to generate output values for \"" + this + "\".";
	throw new ProcessingException(msg, e);
      }
    }

  /**
   * Gets the default Properties.
   *
   * @return Default Processor Properties.
   */
  private static ProcessorProperty[] _getDefaultProperties()
    {
      ProcessorProperty[] properties = new ProcessorProperty[0];
      return properties;
    }
}
